@@ -25,11 +25,7 @@ class CustomEnumMeta(EnumMeta):
         return enum_class
 
     def __contains__(cls, member):
-        if super(CustomEnumMeta, cls).__contains__(member):
-            return True
-        if isinstance(member, str):
-            return member in cls._member_reverse_map
-        return False
+        return member in cls.__members__ or member in cls._member_reverse_map
 
     def __getitem__(self, item):
         try:
@@ -86,6 +82,8 @@ class DEFAULT_ACCOUNT_TYPE(CustomEnum):
 # noinspection PyPep8Naming
 class MATCHING_TYPE(CustomEnum):
     CURRENT_BAR_CLOSE = "CURRENT_BAR_CLOSE"
+    VWAP = "VWAP"
+    COUNTERPARTY_OFFER = "COUNTERPARTY_OFFER"
     NEXT_BAR_OPEN = "NEXT_BAR_OPEN"
     NEXT_TICK_LAST = "NEXT_TICK_LAST"
     NEXT_TICK_BEST_OWN = "NEXT_TICK_BEST_OWN"
@@ -100,12 +98,12 @@ class ORDER_TYPE(CustomEnum):
 
 # noinspection PyPep8Naming
 class ORDER_STATUS(CustomEnum):
-    PENDING_NEW = "PENDING_NEW"
-    ACTIVE = "ACTIVE"
-    FILLED = "FILLED"
-    REJECTED = "REJECTED"
-    PENDING_CANCEL = "PENDING_CANCEL"
-    CANCELLED = "CANCELLED"
+    PENDING_NEW = "PENDING_NEW"        # 待报
+    ACTIVE = "ACTIVE"                  # 已报/部成
+    FILLED = "FILLED"                  # 已成
+    REJECTED = "REJECTED"              # 拒单
+    PENDING_CANCEL = "PENDING_CANCEL"  # 待撤
+    CANCELLED = "CANCELLED"            # 已撤
 
 
 # noinspection PyPep8Naming
@@ -187,16 +185,18 @@ class DAYS_CNT(object):
     TRADING_DAYS_A_YEAR = 252
 
 
-# noinspection PyPep8Naming
-class MARKET(CustomEnum):
-    CN = "CN"
-    HK = "HK"
+class EXCHANGE(CustomEnum):
+    XSHE = "XSHE"
+    XSHG = "XSHG"
+    SHFE = "SHFE"
+    INE = "INE"
+    DCE = "DCE"
+    CZCE = "CZCE"
+    CFFEX = "CFFEX"
+    SGEX = "SGEX"
 
 
 # noinspection PyPep8Naming
 class TRADING_CALENDAR_TYPE(CustomEnum):
     EXCHANGE = "EXCHANGE"
     INTER_BANK = "INTERBANK"
-
-
-UNDERLYING_SYMBOL_PATTERN = "([a-zA-Z]+)\d+"
