@@ -15,29 +15,29 @@
 #         在此前提下，对本软件的使用同样需要遵守 Apache 2.0 许可，Apache 2.0 许可与本许可冲突之处，以本许可为准。
 #         详细的授权流程，请联系 public@ricequant.com 获取。
 
+import codecs
+import json
+import locale
 import os
 import sys
-import locale
-import codecs
-import pickle
 from copy import copy
-from typing import Dict
+from itertools import chain
+from contextlib import contextmanager
+from typing import Dict, Iterable, Optional
 
-from rqalpha.data.base_data_source.storage_interface import AbstractSimpleFactorStore
-from rqalpha.utils.functools import lru_cache
-
-import json
 import h5py
-import pandas
 import numpy as np
-
-from rqalpha.utils.datetime_func import convert_date_to_date_int
-from rqalpha.utils.i18n import gettext as _
+import pandas
 from rqalpha.const import COMMISSION_TYPE, INSTRUMENT_TYPE
 from rqalpha.model.instrument import Instrument
+from rqalpha.utils.datetime_func import convert_date_to_date_int
+from rqalpha.utils.functools import lru_cache
+from rqalpha.utils.i18n import gettext as _
 
-from .storage_interface import AbstractCalendarStore, AbstractInstrumentStore, AbstractDayBarStore, AbstractDateSet
-from .storage_interface import AbstractDividendStore
+from .storage_interface import (AbstractCalendarStore, AbstractDateSet,
+                                AbstractDayBarStore, AbstractDividendStore,
+                                AbstractInstrumentStore,
+                                AbstractSimpleFactorStore)
 
 
 class ExchangeTradingCalendarStore(AbstractCalendarStore):
@@ -87,24 +87,39 @@ class FutureInfoStore(object):
 
 
 class InstrumentStore(AbstractInstrumentStore):
-    SUPPORTED_TYPES = (
-        INSTRUMENT_TYPE.CS, INSTRUMENT_TYPE.FUTURE, INSTRUMENT_TYPE.ETF, INSTRUMENT_TYPE.LOF, INSTRUMENT_TYPE.INDX,
-        INSTRUMENT_TYPE.PUBLIC_FUND,
-    )
+    def __init__(self, instruments, instrument_type):
+        # type: (Iterable[Instrument], INSTRUMENT_TYPE) -> None
+        self._instrument_type = instrument_type
+        self._instruments = {}
+        self._sym_id_map = {}
 
-    def __init__(self, f, future_info_store):
-        # type: (str, FutureInfoStore) -> None
-        with open(f, 'rb') as store:
-            d = pickle.load(store)
+        for ins in instruments:
+            if ins.type != instrument_type:
+                continue
+            self._instruments[ins.order_book_id] = ins
+            self._sym_id_map[ins.symbol] = ins.order_book_id
 
-        self._instruments = []
-        for i in d:
-            ins = Instrument(i, lambda i: future_info_store.get_future_info(i)["tick_size"])
-            if ins.type in self.SUPPORTED_TYPES:
-                self._instruments.append(ins)
+    @property
+    def instrument_type(self):
+        # type: () -> INSTRUMENT_TYPE
+        return self._instrument_type
 
-    def get_all_instruments(self):
-        return self._instruments
+    @property
+    def all_id_and_syms(self):
+        # type: () -> Iterable[str]
+        return chain(self._instruments.keys(), self._sym_id_map.keys())
+
+    def get_instruments(self, id_or_syms):
+        # type: (Optional[Iterable[str]]) -> Iterable[Instrument]
+        if id_or_syms is None:
+            return self._instruments.values()
+        order_book_ids = set()
+        for i in id_or_syms:
+            if i in self._instruments:
+                order_book_ids.add(i)
+            elif i in self._sym_id_map:
+                order_book_ids.add(self._sym_id_map[i])
+        return (self._instruments[i] for i in order_book_ids)
 
 
 class ShareTransformationStore(object):
@@ -120,7 +135,7 @@ class ShareTransformationStore(object):
         return transformation_data["successor"], transformation_data["share_conversion_ratio"]
 
 
-def open_h5(path, *args, **kwargs):
+def _file_path(path):
     # why do this? non-ascii path in windows!!
     if sys.platform == "win32":
         try:
@@ -128,15 +143,35 @@ def open_h5(path, *args, **kwargs):
         except TypeError:
             l = None
         if l and l.lower() == "utf-8":
-            path = path.encode("utf-8")
+            return path.encode("utf-8")
+    return path
+
+
+def open_h5(path, *args, **kwargs):
+    # forward compatible
     try:
-        return h5py.File(path, *args, **kwargs)
+        return h5py.File(_file_path(path), *args, **kwargs)
     except OSError as e:
         raise RuntimeError(_(
             "open data bundle failed, you can remove {} and try to regenerate bundle: {}"
         ).format(path, e))
 
 
+@contextmanager
+def h5_file(path, *args, mode="r", **kwargs):
+    try:
+        h5 = h5py.File(_file_path(path), *args, mode=mode, **kwargs)
+    except OSError as e:
+        raise RuntimeError(_(
+            "open data bundle failed, you can remove {} and try to regenerate bundle: {}"
+        ).format(path, e))
+    else:
+        try:
+            yield h5
+        finally:
+            h5.close()
+
+
 class DayBarStore(AbstractDayBarStore):
     DEFAULT_DTYPE = np.dtype([
         ('datetime', np.uint64),
@@ -150,36 +185,44 @@ class DayBarStore(AbstractDayBarStore):
     def __init__(self, path):
         if not os.path.exists(path):
             raise FileExistsError("File {} not exist，please update bundle.".format(path))
-        self._h5 = open_h5(path, mode="r")
+        self._path = path
 
     def get_bars(self, order_book_id):
-        try:
-            return self._h5[order_book_id][:]
-        except KeyError:
-            return np.empty(0, dtype=self.DEFAULT_DTYPE)
+        with h5_file(self._path) as h5:
+            try:
+                return h5[order_book_id][:]
+            except KeyError:
+                return np.empty(0, dtype=self.DEFAULT_DTYPE)
 
     def get_date_range(self, order_book_id):
-        try:
-            data = self._h5[order_book_id]
-            return data[0]['datetime'], data[-1]['datetime']
-        except KeyError:
-            return 20050104, 20050104
+        with h5_file(self._path) as h5:
+            try:
+                data = h5[order_book_id]
+                return data[0]['datetime'], data[-1]['datetime']
+            except KeyError:
+                return 20050104, 20050104
+
+
+class FutureDayBarStore(DayBarStore):
+    DEFAULT_DTYPE = np.dtype(DayBarStore.DEFAULT_DTYPE.descr + [("open_interest", '<f8')])
 
 
 class DividendStore(AbstractDividendStore):
     def __init__(self, path):
-        self._h5 = open_h5(path, mode="r")
+        self._path = path
 
     def get_dividend(self, order_book_id):
-        try:
-            return self._h5[order_book_id][:]
-        except KeyError:
-            return None
+        with h5_file(self._path) as h5:
+            try:
+                return h5[order_book_id][:]
+            except KeyError:
+                return None
 
 
 class YieldCurveStore:
     def __init__(self, path):
-        self._data = open_h5(path, mode="r")["data"][:]
+        with h5_file(path) as h5:
+            self._data = h5["data"][:]
 
     def get_yield_curve(self, start_date, end_date, tenor):
         d1 = convert_date_to_date_int(start_date)
@@ -207,26 +250,28 @@ class YieldCurveStore:
 
 class SimpleFactorStore(AbstractSimpleFactorStore):
     def __init__(self, path):
-        self._h5 = open_h5(path, mode="r")
+        self._path = path
 
     def get_factors(self, order_book_id):
-        try:
-            return self._h5[order_book_id][:]
-        except KeyError:
-            return None
+        with h5_file(self._path) as h5:
+            try:
+                return h5[order_book_id][:]
+            except KeyError:
+                return None
 
 
 class DateSet(AbstractDateSet):
     def __init__(self, f):
-        self._h5 = open_h5(f, mode="r")
+        self._f = f
 
     @lru_cache(None)
     def get_days(self, order_book_id):
-        try:
-            days = self._h5[order_book_id][:]
+        with h5_file(self._f) as h5:
+            try:
+                days = h5[order_book_id][:]
+            except KeyError:
+                return set()
             return set(days.tolist())
-        except KeyError:
-            return set()
 
     def contains(self, order_book_id, dates):
         date_set = self.get_days(order_book_id)
