@@ -80,15 +80,6 @@ class AbstractPosition(with_metaclass(abc.ABCMeta)):
         """
         raise NotImplementedError
 
-    @property
-    @abc.abstractmethod
-    def margin(self):
-        # type: () -> Union[int, float]
-        """
-        返回当前持仓所占的保证金
-        """
-        raise NotImplementedError
-
     @property
     @abc.abstractmethod
     def transaction_cost(self):
@@ -594,6 +585,7 @@ class AbstractFrontendValidator(with_metaclass(abc.ABCMeta)):
 
     扩展模块可以通过 env.add_frontend_validator 添加自定义的前端风控逻辑
     """
+
     @abc.abstractmethod
     def can_submit_order(self, order, account=None):
         """
