@@ -1,4 +1,4 @@
-from rqalpha.api import *
+from rqalpha.apis import *
 
 
 def init(context):
@@ -15,13 +15,14 @@ def rebalance(context, bar_dict):
 
 __config__ = {
     "base": {
-        "securities": "stock",
         "start_date": "2008-07-01",
         "end_date": "2017-01-01",
         "frequency": "1d",
         "matching_type": "current_bar",
-        "stock_starting_cash": 100000,
         "benchmark": "000001.XSHE",
+        "accounts": {
+            "stock": 100000
+        }
     },
     "extra": {
         "log_level": "error",
